package com.ruoyi.tcZz.service;

import java.util.List;

import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.domain.TcYqbg;

/**
 * 舆情报告Service接口
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
public interface ITcYqbgService 
{
    /**
     * 查询舆情报告
     * 
     * @param id 舆情报告主键
     * @return 舆情报告
     */
    public TcYqbg selectTcYqbgById(Long id);

    /**
     * 查询舆情报告列表
     * 
     * @param tcYqbg 舆情报告
     * @return 舆情报告集合
     */
    public List<TcYqbg> selectTcYqbgList(TcYqbg tcYqbg);

    /**
     * 新增舆情报告
     * 
     * @param tcYqbg 舆情报告
     * @return 结果
     */
    public int insertTcYqbg(TcYqbg tcYqbg);

    /**
     * 修改舆情报告
     * 
     * @param tcYqbg 舆情报告
     * @return 结果
     */
    public int updateTcYqbg(TcYqbg tcYqbg);

    /**
     * 批量删除舆情报告
     * 
     * @param ids 需要删除的舆情报告主键集合
     * @return 结果
     */
    public int deleteTcYqbgByIds(Long[] ids);

    /**
     * 删除舆情报告信息
     * 
     * @param id 舆情报告主键
     * @return 结果
     */
    public int deleteTcYqbgById(Long id);


    /**
     * 导入舆情报告信息
     *
     * @return 结果
     */
    public String importUser(List<TcYqbg> tcYqbgList);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(Integer isStatus,List<String> ids);
}
