package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.domain.TcWz;
import com.ruoyi.tcZz.domain.TcXtjc;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcYqbg;
import com.ruoyi.tcZz.service.ITcYqbgService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 舆情报告Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@Api(tags = "舆情报告")
@RequestMapping("/tcZz/netWorkYq/yqbg")
public class TcYqbgController extends BaseController
{
    @Autowired
    private ITcYqbgService tcYqbgService;

    /**
     * 查询舆情报告列表
     */
    @ApiOperation(value = "查询舆情报告列表", response = TcYqbg.class)
    @GetMapping("/list")
    public TableDataInfo list(TcYqbg tcYqbg)
    {
        startPage();
        List<TcYqbg> list = tcYqbgService.selectTcYqbgList(tcYqbg);
        return getDataTable(list);
    }

    /**
     * 导出舆情报告列表
     */
    @ApiOperation(value = "导出舆情报告列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcYqbg tcYqbg)
    {
        List<TcYqbg> list = tcYqbgService.selectTcYqbgList(tcYqbg);
        ExcelUtil<TcYqbg> util = new ExcelUtil<TcYqbg>(TcYqbg.class);
        util.exportExcel(response, list, "舆情报告数据");
    }

    /**
     * 获取舆情报告详细信息
     */
    @ApiOperation(value = "获取舆情报告详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcYqbgService.selectTcYqbgById(id));
    }

    /**
     * 新增舆情报告
     */
    @ApiOperation(value = "新增舆情报告")
    @PostMapping
    public AjaxResult add(@RequestBody TcYqbg tcYqbg)
    {
        return toAjax(tcYqbgService.insertTcYqbg(tcYqbg));
    }

    /**
     * 修改舆情报告
     */
    @ApiOperation(value = "修改舆情报告")
    @PutMapping
    public AjaxResult edit(@RequestBody TcYqbg tcYqbg)
    {
        return toAjax(tcYqbgService.updateTcYqbg(tcYqbg));
    }

    /**
     * 删除舆情报告
     */
    @ApiOperation(value = "删除舆情报告")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcYqbgService.deleteTcYqbgByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcYqbg> util = new ExcelUtil<TcYqbg>(TcYqbg.class);
        List<TcYqbg> tcYqbgList = util.importExcel(file.getInputStream());
        tcYqbgService.importUser(tcYqbgList);
        return AjaxResult.success();
    }
    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcYqbgService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcYqbg> util = new ExcelUtil<TcYqbg>(TcYqbg.class);
        util.importTemplateExcel(response, " 舆情报告");
    }
}
